@@ -18,7 +18,7 @@ use structopt::StructOpt;
 /// The options
 #[derive(StructOpt, Debug, PartialEq)]
 pub struct Opt {
-    #[structopt(short = "v")]
+    #[structopt(short)]
     verbose: bool,
     #[structopt(subcommand)]
     cmd: Option<Cmd>,
@@ -32,7 +32,7 @@ pub enum Cmd {
     /// command B
     B {
         /// Alice?
-        #[structopt(short = "a")]
+        #[structopt(short)]
         alice: bool,
     },
     /// command C
@@ -42,7 +42,7 @@ pub enum Cmd {
 /// The options for C
 #[derive(StructOpt, Debug, PartialEq)]
 pub struct COpt {
-    #[structopt(short = "b")]
+    #[structopt(short)]
     bob: bool,
 }
 
